function [MatchID, MatchData, Matchlsq] = SpectralDbComparison(v_abs,spec, db)
%% ===== HELP ====== 
% This function  performs the comparison with a spectral database  returning the first matches
% Inputs: v_abs = [vabs, sigma_vabs] absolute reflectance in the v filter
%         spec  = [b, v=1, w, x] - spectrophtometric data (it should come already normalized)
%         db - spectral database. It must come as a structure with two components: 
%                                 db.ID - IDs to identify the indexes
%                                 db.data - data having the absolute reflectances on each line
% Outputs: MatchID  - the IDs of the first nout macthes
%          MatchData - the data for the first nnout matches
%          Matchlsq - least squared errors of the matches 
%
% Created by Marcel Popescu, popescu.marcel1983@gmail.com
% Date: 30 December 2020
%% ==================

% Configuration parameters
% Number of matches to output
nout = 5;
% Interval (as a number of sigma_vabs) for absoulte reflectances for which the match is acceptable
nsigabs = 3;
% Idx of column for normalization
idxnorm = 2;
% Work with normalized or unormalized data
not_norm = 0;

% Select the data which is in the absolute reflectances interval
idx_sel_abs_ref = intersect( find(db.data(:,idxnorm)>=(v_abs(1) - nsigabs * v_abs(2))), ...
                             find(db.data(:,idxnorm)<=(v_abs(1) + nsigabs * v_abs(2))) ...
                  );
printf("\n A number of %d spectra remined after the albedo selection\n", length(idx_sel_abs_ref));

IDs = db.ID(idx_sel_abs_ref); % I have used round to deal with IDs from mixtures, but it should not be used anymore
try
    IDs = round(IDs);
catch
ones(1,1);
end
DataRef = db.data(idx_sel_abs_ref, :);

%Use the algoritm you prefer with spectra nor
if not_norm
    % Find the least square errors
    lsqerr = sum((DataRef - repmat(spec(1,:).*v_abs(1), size(DataRef,1), 1)).^2,2);
else
    % Normalize the refrence data
    for idxc = 1:size(DataRef,2)
        DataRefNorm(:, idxc) = DataRef(:, idxc) ./ DataRef(:, idxnorm);
    end
    % Find the least square errors
    lsqerr = sum((DataRefNorm - repmat(spec(1,:), size(DataRef,1), 1)).^2,2);
end


% Sort the errors in the ascending order
[Matchlsq, MatchIdx] = sort(lsqerr);
% Prepare the outputs


MatchID = IDs(MatchIdx)([1:nout]);
MatchData = DataRef(MatchIdx,:)([1:nout],:);
Matchlsq = Matchlsq([1:nout]);

%{
%% THIS IS EXPERIMENTAL STUFF FOR DEALING WITH BENNU AVERAGE AND METEORITES
mlsq = Matchlsq(1);
midx = MatchIdx(1);
for idxaux = 1: nout-1
    f = floor(IDs(MatchIdx)/1e5)/100;
    n = floor(IDs(MatchIdx) - f.*100.*1e5);

    idxrm = find(n==n(1));
    Matchlsq(idxrm) = []; MatchIdx(idxrm) = [];

    mlsq = [mlsq, Matchlsq(1)];
    midx = [midx, MatchIdx(1)];
end
Matchlsq = mlsq;
MatchIdx = midx;

MatchID = IDs(MatchIdx)([1:nout]);
MatchData = DataRef(MatchIdx,:)([1:nout],:);
Matchlsq = Matchlsq([1:nout]);
%}
