function [out,l2w] = getMAPCAMcolors(datain)


%% Load filters transfer function
data = load('/home/marcel/Documents/Osirisrex/Data/FiltersQE.csv');
#x,b,v,w,x,pan
wlf = data(:,1);
data(find(diff(wlf)==0),:) = [];
wlf = data(:,1);
bf  = data(:,2);
vf  = data(:,3);
wf  = data(:,4);
xf  = data(:,5);
pf  = data(:,6); % pnachormatic filter
%% --------------

%% Load wavelength and reflectance of the input data
wls = datain(:,1);
rfs = datain(:,2);
% Issue error if insuficient spectral coverage
if (wls(1)>0.42) || wls(end)<0.92
    error('Insuficient spectral coverage');
end
%% --------------

%% Interpolate to a common wavelength vector
wl = 0.42:1e-4:0.92; % ste of 0.1 um
rfsi = interp1(wls,rfs,wl,'linear');
bfi  = interp1(wlf,bf,wl,'linear');
vfi  = interp1(wlf,vf,wl,'linear');
wfi  = interp1(wlf,wf,wl,'linear');
xfi  = interp1(wlf,xf,wl,'linear');
pfi  = interp1(wlf,pf,wl,'linear');
%% --------------

%% Compute refelctances corresponding to each filter 
rb = sum(rfsi.*bfi)./sum(bfi);
rv = sum(rfsi.*vfi)./sum(vfi);
rw = sum(rfsi.*wfi)./sum(wfi);
rx = sum(rfsi.*xfi)./sum(xfi);
rp = sum(rfsi.*pfi)./sum(pfi);

% Compute the average wavelength
wlb = mean(wl(find(bfi>0.1)));
wlv = mean(wl(find(vfi>0.1)));
wlw = mean(wl(find(wfi>0.1)));
wlx = mean(wl(find(xfi>0.1)));
wlp = mean(wl(find(pfi>0.1)));

% Prepare the output vector
out = [ wlb, rb;
        wlv, rv;
        wlw, rw;
        wlx, rx;
        wlp, rp;];
l2w = sprintf("%.4f,%.4f,%.4f,%.4f,%.4f", [rb, rv,rw, rx,rp]);


if(0)
    figure(1)
    plot(wl,bfi,'-r', "Linewidth", 2);
    hold on
    plot(wl,vfi,'-r', "Linewidth", 2);
    plot(wl,wfi,'-r', "Linewidth", 2);
    plot(wl,xfi,'-r', "Linewidth", 2);
    plot(wl,pfi,'-k', "Linewidth", 2);

    plot(wl,rfsi./mean(rfsi)-0.8,'*b', "Linewidth", 0.5);
    hold off
    set(gca,'Fontsize',22);
    set(gca,'ytick',[])
    xlim([0.4, 0.92]);
    ylim([0 1.1]);
    legend('b','v','w','x','pan',"location",'north',"orientation",'horizontal');
    xlabel('Wavelength [um]');
    ylabel('Transmitance');
end
